countries <- c("Germany", "Spain")

resources <- c("RES","Nuclear","Coal", "Gas")
resources_trade <- c("RES", "RES_import", "Nuclear", "Nuclear_import", 
                    "Coal", "Coal_import", "Gas", "Gas_import")

#### GERMANY + SPAIN

germany <- read.delim("data/germany.csv", sep="\t", header=T)

spain <- read.delim("data/spain.csv", sep="\t", header=T)

renews_de_big <- data.frame(de_solar = germany$eastde_solar + 
						germany$westde_solar + 
						germany$centerde_solar + 
						germany$southde_solar, 
					de_wind = as.numeric(germany$eastde_wind) + 
						germany$westde_wind + 
						germany$centerde_wind + 
						germany$southde_wind,
					de_load = as.numeric(germany$eastde_load) + 
						germany$westde_load + 
						germany$centerde_load + 
						germany$southde_load)
                        
renews_de <- renews_de_big[(1:8783)*4,]
renews_es <- data.frame(es_solar = spain$es_solarpv + 
						spain$es_solarth, 
					es_wind = spain$es_wind,
					es_load = spain$es_load)
renews <- cbind(renews_de, renews_es)
renews <- na.omit(renews)

freq <- dim(renews)[1]
print(freq)

## res supply
res <- matrix(0, nrow=freq, ncol=2)

colnames(res) <- countries

res[,1] <- renews$de_solar + renews$de_wind
res[,2] <- renews$es_solar + renews$es_wind

res[,1] <- res[,1]/max(res[,1])
res[,2] <- res[,2]/max(res[,2])


## SUPPLY/FOSSIL and NUCLEAR
gas <- nuc <- coa <- matrix(1, ncol=2, nrow=freq)
colnames(gas) <- colnames(nuc) <- colnames(coa) <- countries

## DEMAND: 
baseload <- matrix(0, nrow=freq, ncol=2)
perc_load <- matrix(0, nrow=freq, ncol=2)
baseload[,1] <- renews$de_load + renews$de_solar + renews$de_wind
baseload[,2] <- renews$es_load

maxload <- apply(baseload, 2, max)
minload <- 0 # apply(baseload, 2, min)  

perc_load[,1] <- baseload[,1]/maxload[1]
perc_load[,2] <- baseload[,2]/maxload[2] 	

colnames(perc_load) <- countries
summary(perc_load)

# peak load
peak_load <- c(0,0)
names(peak_load) <- countries
peak_load["Germany"] <- c(peak_A)
peak_load["Spain"] <- c(peak_B)

# total capacity
tot_cap <- c(0,0)
names(tot_cap) <- countries
tot_cap["Germany"] <- sum(c(res_A+gas_A+coal_A+nuclear_A))
tot_cap["Spain"] <- sum(c(res_B+gas_B+coal_B+nuclear_B))

# Demand values: peak*perc_load
demand <- matrix(0, nrow=freq, ncol=2)
colnames(demand) <- countries
for(c in countries){ demand[,c] <- peak_load[c]*perc_load[,c] }

demand[which(demand[,1]==max(demand[,1])),1] <- demand[which(demand[,1]==max(demand[,1])),1]*1.1
demand[which(demand[,2]==max(demand[,2])),2] <- demand[which(demand[,2]==max(demand[,2])),2]*1.1


# variable costs
vc <- matrix(0, nrow=8, ncol=2)
rownames(vc) <- resources_trade
colnames(vc) <- countries

vc[,"Germany"] <- c(vc_res, vc_res+0.1, vc_nuclear, vc_nuclear+0.1, vc_coal, vc_coal+0.1, vc_gas, vc_gas+0.1)
vc[,"Spain"] <- c(vc_res, vc_res+0.1, vc_nuclear, vc_nuclear+0.1, vc_coal, vc_coal+0.1, vc_gas, vc_gas+0.1)

# exceeding cost (variable)
exceed <- cost_over

# fixed costs
fc <- matrix(0, nrow=4, ncol=2)
rownames(fc) <- resources
colnames(fc) <- countries

fc[,"Spain"] <- c(fc_res, fc_nuclear, fc_coal, fc_gas)
fc[,"Germany"] <- c(fc_res, fc_nuclear, fc_coal, fc_gas)


# Calculate trade limits
trbase <- min(tot_cap)
trlim <- cbind(rep(trbase,freq),rep(trbase,freq))*trade_perc
colnames(trlim) <- countries
